---
title: Spring
id: spring
layout: default.haml
author: Henry David Thoreau
date: 2018-04-15
chapter: 17
kind: article
---

## Spring

The opening of large tracts by the ice-cutters commonly causes a pond
to break up earlier; for the water, agitated by the wind, even in cold
weather, wears away the surrounding ice. But such was not the effect on
Walden that year, for she had soon got a thick new garment to take the
place of the old. This pond never breaks up so soon as the others in
this neighborhood, on account both of its greater depth and its having
no stream passing through it to melt or wear away the ice. I never knew
it to open in the course of a winter, not excepting that of ’52–3,
which gave the ponds so severe a trial. It commonly opens about the
first of April, a week or ten days later than Flint’s Pond and
Fair-Haven, beginning to melt on the north side and in the shallower
parts where it began to freeze. It indicates better than any water
hereabouts the absolute progress of the season, being least affected by
transient changes of temperature. A severe cold of a few days’ duration
in March may very much retard the opening of the former ponds, while
the temperature of Walden increases almost uninterruptedly. A
thermometer thrust into the middle of Walden on the 6th of March, 1847,
stood at 32°, or freezing point; near the shore at 33°; in the middle
of Flint’s Pond, the same day, at 32½°; at a dozen rods from the shore,
in shallow water, under ice a foot thick, at 36°. This difference of
three and a half degrees between the temperature of the deep water and
the shallow in the latter pond, and the fact that a great proportion of
it is comparatively shallow, show why it should break up so much sooner
than Walden. The ice in the shallowest part was at this time several
inches thinner than in the middle. In mid-winter the middle had been
the warmest and the ice thinnest there. So, also, every one who has
waded about the shores of the pond in summer must have perceived how
much warmer the water is close to the shore, where only three or four
inches deep, than a little distance out, and on the surface where it is
deep, than near the bottom. In spring the sun not only exerts an
influence through the increased temperature of the air and earth, but
its heat passes through ice a foot or more thick, and is reflected from
the bottom in shallow water, and so also warms the water and melts the
under side of the ice, at the same time that it is melting it more
directly above, making it uneven, and causing the air bubbles which it
contains to extend themselves upward and downward until it is
completely honeycombed, and at last disappears suddenly in a single
spring rain. Ice has its grain as well as wood, and when a cake begins
to rot or “comb,” that is, assume the appearance of honey-comb,
whatever may be its position, the air cells are at right angles with
what was the water surface. Where there is a rock or a log rising near
to the surface the ice over it is much thinner, and is frequently quite
dissolved by this reflected heat; and I have been told that in the
experiment at Cambridge to freeze water in a shallow wooden pond,
though the cold air circulated underneath, and so had access to both
sides, the reflection of the sun from the bottom more than
counterbalanced this advantage. When a warm rain in the middle of the
winter melts off the snow-ice from Walden, and leaves a hard dark or
transparent ice on the middle, there will be a strip of rotten though
thicker white ice, a rod or more wide, about the shores, created by
this reflected heat. Also, as I have said, the bubbles themselves
within the ice operate as burning-glasses to melt the ice beneath.

The phenomena of the year take place every day in a pond on a small
scale. Every morning, generally speaking, the shallow water is being
warmed more rapidly than the deep, though it may not be made so warm
after all, and every evening it is being cooled more rapidly until the
morning. The day is an epitome of the year. The night is the winter,
the morning and evening are the spring and fall, and the noon is the
summer. The cracking and booming of the ice indicate a change of
temperature. One pleasant morning after a cold night, February 24th,
1850, having gone to Flint’s Pond to spend the day, I noticed with
surprise, that when I struck the ice with the head of my axe, it
resounded like a gong for many rods around, or as if I had struck on a
tight drum-head. The pond began to boom about an hour after sunrise,
when it felt the influence of the sun’s rays slanted upon it from over
the hills; it stretched itself and yawned like a waking man with a
gradually increasing tumult, which was kept up three or four hours. It
took a short siesta at noon, and boomed once more toward night, as the
sun was withdrawing his influence. In the right stage of the weather a
pond fires its evening gun with great regularity. But in the middle of
the day, being full of cracks, and the air also being less elastic, it
had completely lost its resonance, and probably fishes and muskrats
could not then have been stunned by a blow on it. The fishermen say
that the “thundering of the pond” scares the fishes and prevents their
biting. The pond does not thunder every evening, and I cannot tell
surely when to expect its thundering; but though I may perceive no
difference in the weather, it does. Who would have suspected so large
and cold and thick-skinned a thing to be so sensitive? Yet it has its
law to which it thunders obedience when it should as surely as the buds
expand in the spring. The earth is all alive and covered with papillæ.
The largest pond is as sensitive to atmospheric changes as the globule
of mercury in its tube.



One attraction in coming to the woods to live was that I should have
leisure and opportunity to see the spring come in. The ice in the pond
at length begins to be honey-combed, and I can set my heel in it as I
walk. Fogs and rains and warmer suns are gradually melting the snow;
the days have grown sensibly longer; and I see how I shall get through
the winter without adding to my wood-pile, for large fires are no
longer necessary. I am on the alert for the first signs of spring, to
hear the chance note of some arriving bird, or the striped squirrel’s
chirp, for his stores must be now nearly exhausted, or see the
woodchuck venture out of his winter quarters. On the 13th of March,
after I had heard the bluebird, song-sparrow, and red-wing, the ice was
still nearly a foot thick. As the weather grew warmer it was not
sensibly worn away by the water, nor broken up and floated off as in
rivers, but, though it was completely melted for half a rod in width
about the shore, the middle was merely honey-combed and saturated with
water, so that you could put your foot through it when six inches
thick; but by the next day evening, perhaps, after a warm rain followed
by fog, it would have wholly disappeared, all gone off with the fog,
spirited away. One year I went across the middle only five days before
it disappeared entirely. In 1845 Walden was first completely open on
the 1st of April; in ’46, the 25th of March; in ’47, the 8th of April;
in ’51, the 28th of March; in ’52, the 18th of April; in ’53, the 23d
of March; in ’54, about the 7th of April.

Every incident connected with the breaking up of the rivers and ponds
and the settling of the weather is particularly interesting to us who
live in a climate of so great extremes. When the warmer days come, they
who dwell near the river hear the ice crack at night with a startling
whoop as loud as artillery, as if its icy fetters were rent from end to
end, and within a few days see it rapidly going out. So the alligator
comes out of the mud with quakings of the earth. One old man, who has
been a close observer of Nature, and seems as thoroughly wise in regard
to all her operations as if she had been put upon the stocks when he
was a boy, and he had helped to lay her keel,—who has come to his
growth, and can hardly acquire more of natural lore if he should live
to the age of Methuselah,—told me, and I was surprised to hear him
express wonder at any of Nature’s operations, for I thought that there
were no secrets between them, that one spring day he took his gun and
boat, and thought that he would have a little sport with the ducks.
There was ice still on the meadows, but it was all gone out of the
river, and he dropped down without obstruction from Sudbury, where he
lived, to Fair-Haven Pond, which he found, unexpectedly, covered for
the most part with a firm field of ice. It was a warm day, and he was
surprised to see so great a body of ice remaining. Not seeing any
ducks, he hid his boat on the north or back side of an island in the
pond, and then concealed himself in the bushes on the south side, to
await them. The ice was melted for three or four rods from the shore,
and there was a smooth and warm sheet of water, with a muddy bottom,
such as the ducks love, within, and he thought it likely that some
would be along pretty soon. After he had lain still there about an hour
he heard a low and seemingly very distant sound, but singularly grand
and impressive, unlike any thing he had ever heard, gradually swelling
and increasing as if it would have a universal and memorable ending, a
sullen rush and roar, which seemed to him all at once like the sound of
a vast body of fowl coming in to settle there, and, seizing his gun, he
started up in haste and excited; but he found, to his surprise, that
the whole body of the ice had started while he lay there, and drifted
in to the shore, and the sound he had heard was made by its edge
grating on the shore,—at first gently nibbled and crumbled off, but at
length heaving up and scattering its wrecks along the island to a
considerable height before it came to a stand still.

At length the sun’s rays have attained the right angle, and warm winds
blow up mist and rain and melt the snow banks, and the sun dispersing
the mist smiles on a checkered landscape of russet and white smoking
with incense, through which the traveller picks his way from islet to
islet, cheered by the music of a thousand tinkling rills and rivulets
whose veins are filled with the blood of winter which they are bearing
off.

Few phenomena gave me more delight than to observe the forms which
thawing sand and clay assume in flowing down the sides of a deep cut on
the railroad through which I passed on my way to the village, a
phenomenon not very common on so large a scale, though the number of
freshly exposed banks of the right material must have been greatly
multiplied since railroads were invented. The material was sand of
every degree of fineness and of various rich colors, commonly mixed
with a little clay. When the frost comes out in the spring, and even in
a thawing day in the winter, the sand begins to flow down the slopes
like lava, sometimes bursting out through the snow and overflowing it
where no sand was to be seen before. Innumerable little streams overlap
and interlace one with another, exhibiting a sort of hybrid product,
which obeys half way the law of currents, and half way that of
vegetation. As it flows it takes the forms of sappy leaves or vines,
making heaps of pulpy sprays a foot or more in depth, and resembling,
as you look down on them, the laciniated, lobed, and imbricated
thalluses of some lichens; or you are reminded of coral, of leopard’s
paws or birds’ feet, of brains or lungs or bowels, and excrements of
all kinds. It is a truly _grotesque_ vegetation, whose forms and color
we see imitated in bronze, a sort of architectural foliage more ancient
and typical than acanthus, chiccory, ivy, vine, or any vegetable
leaves; destined perhaps, under some circumstances, to become a puzzle
to future geologists. The whole cut impressed me as if it were a cave
with its stalactites laid open to the light. The various shades of the
sand are singularly rich and agreeable, embracing the different iron
colors, brown, gray, yellowish, and reddish. When the flowing mass
reaches the drain at the foot of the bank it spreads out flatter into
_strands_, the separate streams losing their semi-cylindrical form and
gradually becoming more flat and broad, running together as they are
more moist, till they form an almost flat _sand_, still variously and
beautifully shaded, but in which you can trace the original forms of
vegetation; till at length, in the water itself, they are converted
into _banks_, like those formed off the mouths of rivers, and the forms
of vegetation are lost in the ripple marks on the bottom.

The whole bank, which is from twenty to forty feet high, is sometimes
overlaid with a mass of this kind of foliage, or sandy rupture, for a
quarter of a mile on one or both sides, the produce of one spring day.
What makes this sand foliage remarkable is its springing into existence
thus suddenly. When I see on the one side the inert bank,—for the sun
acts on one side first,—and on the other this luxuriant foliage, the
creation of an hour, I am affected as if in a peculiar sense I stood in
the laboratory of the Artist who made the world and me,—had come to
where he was still at work, sporting on this bank, and with excess of
energy strewing his fresh designs about. I feel as if I were nearer to
the vitals of the globe, for this sandy overflow is something such a
foliaceous mass as the vitals of the animal body. You find thus in the
very sands an anticipation of the vegetable leaf. No wonder that the
earth expresses itself outwardly in leaves, it so labors with the idea
inwardly. The atoms have already learned this law, and are pregnant by
it. The overhanging leaf sees here its prototype. _Internally_, whether
in the globe or animal body, it is a moist thick _lobe_, a word
especially applicable to the liver and lungs and the _leaves_ of fat,
(?e?ß?, _labor_, _lapsus_, to flow or slip downward, a lapsing; ??ß??,
_globus_, lobe, globe; also lap, flap, and many other words,)
_externally_ a dry thin _leaf_, even as the _f_ and _v_ are a pressed
and dried _b_. The radicals of _lobe_ are _lb_, the soft mass of the
_b_ (single lobed, or B, double lobed,) with the liquid _l_ behind it
pressing it forward. In globe, _glb_, the guttural _g_ adds to the
meaning the capacity of the throat. The feathers and wings of birds are
still drier and thinner leaves. Thus, also, you pass from the lumpish
grub in the earth to the airy and fluttering butterfly. The very globe
continually transcends and translates itself, and becomes winged in its
orbit. Even ice begins with delicate crystal leaves, as if it had
flowed into moulds which the fronds of water plants have impressed on
the watery mirror. The whole tree itself is but one leaf, and rivers
are still vaster leaves whose pulp is intervening earth, and towns and
cities are the ova of insects in their axils.

When the sun withdraws the sand ceases to flow, but in the morning the
streams will start once more and branch and branch again into a myriad
of others. You here see perchance how blood vessels are formed. If you
look closely you observe that first there pushes forward from the
thawing mass a stream of softened sand with a drop-like point, like the
ball of the finger, feeling its way slowly and blindly downward, until
at last with more heat and moisture, as the sun gets higher, the most
fluid portion, in its effort to obey the law to which the most inert
also yields, separates from the latter and forms for itself a
meandering channel or artery within that, in which is seen a little
silvery stream glancing like lightning from one stage of pulpy leaves
or branches to another, and ever and anon swallowed up in the sand. It
is wonderful how rapidly yet perfectly the sand organizes itself as it
flows, using the best material its mass affords to form the sharp edges
of its channel. Such are the sources of rivers. In the silicious matter
which the water deposits is perhaps the bony system, and in the still
finer soil and organic matter the fleshy fibre or cellular tissue. What
is man but a mass of thawing clay? The ball of the human finger is but
a drop congealed. The fingers and toes flow to their extent from the
thawing mass of the body. Who knows what the human body would expand
and flow out to under a more genial heaven? Is not the hand a spreading
_palm_ leaf with its lobes and veins? The ear may be regarded,
fancifully, as a lichen, _umbilicaria_, on the side of the head, with
its lobe or drop. The lip—_labium_, from _labor_ (?)—laps or lapses
from the sides of the cavernous mouth. The nose is a manifest congealed
drop or stalactite. The chin is a still larger drop, the confluent
dripping of the face. The cheeks are a slide from the brows into the
valley of the face, opposed and diffused by the cheek bones. Each
rounded lobe of the vegetable leaf, too, is a thick and now loitering
drop, larger or smaller; the lobes are the fingers of the leaf; and as
many lobes as it has, in so many directions it tends to flow, and more
heat or other genial influences would have caused it to flow yet
farther.

Thus it seemed that this one hillside illustrated the principle of all
the operations of Nature. The Maker of this earth but patented a leaf.
What Champollion will decipher this hieroglyphic for us, that we may
turn over a new leaf at last? This phenomenon is more exhilarating to
me than the luxuriance and fertility of vineyards. True, it is somewhat
excrementitious in its character, and there is no end to the heaps of
liver lights and bowels, as if the globe were turned wrong side
outward; but this suggests at least that Nature has some bowels, and
there again is mother of humanity. This is the frost coming out of the
ground; this is Spring. It precedes the green and flowery spring, as
mythology precedes regular poetry. I know of nothing more purgative of
winter fumes and indigestions. It convinces me that Earth is still in
her swaddling clothes, and stretches forth baby fingers on every side.
Fresh curls spring from the baldest brow. There is nothing inorganic.
These foliaceous heaps lie along the bank like the slag of a furnace,
showing that Nature is “in full blast” within. The earth is not a mere
fragment of dead history, stratum upon stratum like the leaves of a
book, to be studied by geologists and antiquaries chiefly, but living
poetry like the leaves of a tree, which precede flowers and fruit,—not
a fossil earth, but a living earth; compared with whose great central
life all animal and vegetable life is merely parasitic. Its throes will
heave our exuviæ from their graves. You may melt your metals and cast
them into the most beautiful moulds you can; they will never excite me
like the forms which this molten earth flows out into. And not only it,
but the institutions upon it, are plastic like clay in the hands of the
potter.



Ere long, not only on these banks, but on every hill and plain and in
every hollow, the frost comes out of the ground like a dormant
quadruped from its burrow, and seeks the sea with music, or migrates to
other climes in clouds. Thaw with his gentle persuasion is more
powerful than Thor with his hammer. The one melts, the other but breaks
in pieces.

When the ground was partially bare of snow, and a few warm days had
dried its surface somewhat, it was pleasant to compare the first tender
signs of the infant year just peeping forth with the stately beauty of
the withered vegetation which had withstood the
winter,—life-everlasting, golden-rods, pinweeds, and graceful wild
grasses, more obvious and interesting frequently than in summer even,
as if their beauty was not ripe till then; even cotton-grass,
cat-tails, mulleins, johnswort, hard-hack, meadow-sweet, and other
strong stemmed plants, those unexhausted granaries which entertain the
earliest birds,—decent weeds, at least, which widowed Nature wears. I
am particularly attracted by the arching and sheaf-like top of the
wool-grass; it brings back the summer to our winter memories, and is
among the forms which art loves to copy, and which, in the vegetable
kingdom, have the same relation to types already in the mind of man
that astronomy has. It is an antique style older than Greek or
Egyptian. Many of the phenomena of Winter are suggestive of an
inexpressible tenderness and fragile delicacy. We are accustomed to
hear this king described as a rude and boisterous tyrant; but with the
gentleness of a lover he adorns the tresses of Summer.

At the approach of spring the red-squirrels got under my house, two at
a time, directly under my feet as I sat reading or writing, and kept up
the queerest chuckling and chirruping and vocal pirouetting and
gurgling sounds that ever were heard; and when I stamped they only
chirruped the louder, as if past all fear and respect in their mad
pranks, defying humanity to stop them. No you
don’t—chickaree—chickaree. They were wholly deaf to my arguments, or
failed to perceive their force, and fell into a strain of invective
that was irresistible.

The first sparrow of spring! The year beginning with younger hope than
ever! The faint silvery warblings heard over the partially bare and
moist fields from the blue-bird, the song-sparrow, and the red-wing, as
if the last flakes of winter tinkled as they fell! What at such a time
are histories, chronologies, traditions, and all written revelations?
The brooks sing carols and glees to the spring. The marsh-hawk sailing
low over the meadow is already seeking the first slimy life that
awakes. The sinking sound of melting snow is heard in all dells, and
the ice dissolves apace in the ponds. The grass flames up on the
hillsides like a spring fire,—“et primitus oritur herba imbribus
primoribus evocata,”—as if the earth sent forth an inward heat to greet
the returning sun; not yellow but green is the color of its flame;—the
symbol of perpetual youth, the grass-blade, like a long green ribbon,
streams from the sod into the summer, checked indeed by the frost, but
anon pushing on again, lifting its spear of last year’s hay with the
fresh life below. It grows as steadily as the rill oozes out of the
ground. It is almost identical with that, for in the growing days of
June, when the rills are dry, the grass blades are their channels, and
from year to year the herds drink at this perennial green stream, and
the mower draws from it betimes their winter supply. So our human life
but dies down to its root, and still puts forth its green blade to
eternity.

Walden is melting apace. There is a canal two rods wide along the
northerly and westerly sides, and wider still at the east end. A great
field of ice has cracked off from the main body. I hear a song-sparrow
singing from the bushes on the shore,—_olit_, _olit_, _olit,_—_chip_,
_chip_, _chip_, _che char_,—_che wiss_, _wiss_, _wiss_. He too is
helping to crack it. How handsome the great sweeping curves in the edge
of the ice, answering somewhat to those of the shore, but more regular!
It is unusually hard, owing to the recent severe but transient cold,
and all watered or waved like a palace floor. But the wind slides
eastward over its opaque surface in vain, till it reaches the living
surface beyond. It is glorious to behold this ribbon of water sparkling
in the sun, the bare face of the pond full of glee and youth, as if it
spoke the joy of the fishes within it, and of the sands on its shore,—a
silvery sheen as from the scales of a _leuciscus_, as it were all one
active fish. Such is the contrast between winter and spring. Walden was
dead and is alive again. But this spring it broke up more steadily, as
I have said.

The change from storm and winter to serene and mild weather, from dark
and sluggish hours to bright and elastic ones, is a memorable crisis
which all things proclaim. It is seemingly instantaneous at last.
Suddenly an influx of light filled my house, though the evening was at
hand, and the clouds of winter still overhung it, and the eaves were
dripping with sleety rain. I looked out the window, and lo! where
yesterday was cold gray ice there lay the transparent pond already calm
and full of hope as in a summer evening, reflecting a summer evening
sky in its bosom, though none was visible overhead, as if it had
intelligence with some remote horizon. I heard a robin in the distance,
the first I had heard for many a thousand years, methought, whose note
I shall not forget for many a thousand more,—the same sweet and
powerful song as of yore. O the evening robin, at the end of a New
England summer day! If I could ever find the twig he sits upon! I mean
_he_; I mean _the twig_. This at least is not the _Turdus migratorius_.
The pitch-pines and shrub-oaks about my house, which had so long
drooped, suddenly resumed their several characters, looked brighter,
greener, and more erect and alive, as if effectually cleansed and
restored by the rain. I knew that it would not rain any more. You may
tell by looking at any twig of the forest, ay, at your very wood-pile,
whether its winter is past or not. As it grew darker, I was startled by
the _honking_ of geese flying low over the woods, like weary travellers
getting in late from southern lakes, and indulging at last in
unrestrained complaint and mutual consolation. Standing at my door, I
could hear the rush of their wings; when, driving toward my house, they
suddenly spied my light, and with hushed clamor wheeled and settled in
the pond. So I came in, and shut the door, and passed my first spring
night in the woods.

In the morning I watched the geese from the door through the mist,
sailing in the middle of the pond, fifty rods off, so large and
tumultuous that Walden appeared like an artificial pond for their
amusement. But when I stood on the shore they at once rose up with a
great flapping of wings at the signal of their commander, and when they
had got into rank circled about over my head, twenty-nine of them, and
then steered straight to Canada, with a regular _honk_ from the leader
at intervals, trusting to break their fast in muddier pools. A “plump”
of ducks rose at the same time and took the route to the north in the
wake of their noisier cousins.

For a week I heard the circling, groping clangor of some solitary goose
in the foggy mornings, seeking its companion, and still peopling the
woods with the sound of a larger life than they could sustain. In April
the pigeons were seen again flying express in small flocks, and in due
time I heard the martins twittering over my clearing, though it had not
seemed that the township contained so many that it could afford me any,
and I fancied that they were peculiarly of the ancient race that dwelt
in hollow trees ere white men came. In almost all climes the tortoise
and the frog are among the precursors and heralds of this season, and
birds fly with song and glancing plumage, and plants spring and bloom,
and winds blow, to correct this slight oscillation of the poles and
preserve the equilibrium of Nature.

As every season seems best to us in its turn, so the coming in of
spring is like the creation of Cosmos out of Chaos and the realization
of the Golden Age.—

     “Eurus ad Auroram Nabathæaque regna recessit,
     Persidaque, et radiis juga subdita matutinis.”

     “The East-Wind withdrew to Aurora and the Nabathæan kingdom,
     And the Persian, and the ridges placed under the morning rays

            *    *    *    *

     Man was born.  Whether that Artificer of things,
     The origin of a better world, made him from the divine seed;
     Or the earth, being recent and lately sundered from the high
     Ether, retained some seeds of cognate heaven.”

A single gentle rain makes the grass many shades greener. So our
prospects brighten on the influx of better thoughts. We should be
blessed if we lived in the present always, and took advantage of every
accident that befell us, like the grass which confesses the influence
of the slightest dew that falls on it; and did not spend our time in
atoning for the neglect of past opportunities, which we call doing our
duty. We loiter in winter while it is already spring. In a pleasant
spring morning all men’s sins are forgiven. Such a day is a truce to
vice. While such a sun holds out to burn, the vilest sinner may return.
Through our own recovered innocence we discern the innocence of our
neighbors. You may have known your neighbor yesterday for a thief, a
drunkard, or a sensualist, and merely pitied or despised him, and
despaired of the world; but the sun shines bright and warm this first
spring morning, re-creating the world, and you meet him at some serene
work, and see how his exhausted and debauched veins expand with still
joy and bless the new day, feel the spring influence with the innocence
of infancy, and all his faults are forgotten. There is not only an
atmosphere of good will about him, but even a savor of holiness groping
for expression, blindly and ineffectually perhaps, like a new-born
instinct, and for a short hour the south hill-side echoes to no vulgar
jest. You see some innocent fair shoots preparing to burst from his
gnarled rind and try another year’s life, tender and fresh as the
youngest plant. Even he has entered into the joy of his Lord. Why the
jailer does not leave open his prison doors,—why the judge does not
dismis his case,—why the preacher does not dismiss his congregation! It
is because they do not obey the hint which God gives them, nor accept
the pardon which he freely offers to all.

“A return to goodness produced each day in the tranquil and beneficent
breath of the morning, causes that in respect to the love of virtue and
the hatred of vice, one approaches a little the primitive nature of
man, as the sprouts of the forest which has been felled. In like manner
the evil which one does in the interval of a day prevents the germs of
virtues which began to spring up again from developing themselves and
destroys them.

“After the germs of virtue have thus been prevented many times from
developing themselves, then the beneficent breath of evening does not
suffice to preserve them. As soon as the breath of evening does not
suffice longer to preserve them, then the nature of man does not differ
much from that of the brute. Men seeing the nature of this man like
that of the brute, think that he has never possessed the innate faculty
of reason. Are those the true and natural sentiments of man?”

     “The Golden Age was first created, which without any avenger
     Spontaneously without law cherished fidelity and rectitude.
     Punishment and fear were not; nor were threatening words read
     On suspended brass; nor did the suppliant crowd fear
     The words of their judge; but were safe without an avenger.
     Not yet the pine felled on its mountains had descended
     To the liquid waves that it might see a foreign world,
     And mortals knew no shores but their own.
            *    *    *    *
     There was eternal spring, and placid zephyrs with warm
     Blasts soothed the flowers born without seed.”

On the 29th of April, as I was fishing from the bank of the river near
the Nine-Acre-Corner bridge, standing on the quaking grass and willow
roots, where the muskrats lurk, I heard a singular rattling sound,
somewhat like that of the sticks which boys play with their fingers,
when, looking up, I observed a very slight and graceful hawk, like a
night-hawk, alternately soaring like a ripple and tumbling a rod or two
over and over, showing the underside of its wings, which gleamed like a
satin ribbon in the sun, or like the pearly inside of a shell. This
sight reminded me of falconry and what nobleness and poetry are
associated with that sport. The Merlin it seemed to me it might be
called: but I care not for its name. It was the most ethereal flight I
had ever witnessed. It did not simply flutter like a butterfly, nor
soar like the larger hawks, but it sported with proud reliance in the
fields of air; mounting again and again with its strange chuckle, it
repeated its free and beautiful fall, turning over and over like a
kite, and then recovering from its lofty tumbling, as if it had never
set its foot on _terra firma_. It appeared to have no companion in the
universe,—sporting there alone,—and to need none but the morning and
the ether with which it played. It was not lonely, but made all the
earth lonely beneath it. Where was the parent which hatched it, its
kindred, and its father in the heavens? The tenant of the air, it
seemed related to the earth but by an egg hatched some time in the
crevice of a crag;—or was its native nest made in the angle of a cloud,
woven of the rainbow’s trimmings and the sunset sky, and lined with
some soft midsummer haze caught up from earth? Its eyry now some cliffy
cloud.

Beside this I got a rare mess of golden and silver and bright cupreous
fishes, which looked like a string of jewels. Ah! I have penetrated to
those meadows on the morning of many a first spring day, jumping from
hummock to hummock, from willow root to willow root, when the wild
river valley and the woods were bathed in so pure and bright a light as
would have waked the dead, if they had been slumbering in their graves,
as some suppose. There needs no stronger proof of immortality. All
things must live in such a light. O Death, where was thy sting? O
Grave, where was thy victory, then?

Our village life would stagnate if it were not for the unexplored
forests and meadows which surround it. We need the tonic of
wildness,—to wade sometimes in marshes where the bittern and the
meadow-hen lurk, and hear the booming of the snipe; to smell the
whispering sedge where only some wilder and more solitary fowl builds
her nest, and the mink crawls with its belly close to the ground. At
the same time that we are earnest to explore and learn all things, we
require that all things be mysterious and unexplorable, that land and
sea be infinitely wild, unsurveyed and unfathomed by us because
unfathomable. We can never have enough of Nature. We must be refreshed
by the sight of inexhaustible vigor, vast and Titanic features, the
sea-coast with its wrecks, the wilderness with its living and its
decaying trees, the thunder cloud, and the rain which lasts three weeks
and produces freshets. We need to witness our own limits transgressed,
and some life pasturing freely where we never wander. We are cheered
when we observe the vulture feeding on the carrion which disgusts and
disheartens us and deriving health and strength from the repast. There
was a dead horse in the hollow by the path to my house, which compelled
me sometimes to go out of my way, especially in the night when the air
was heavy, but the assurance it gave me of the strong appetite and
inviolable health of Nature was my compensation for this. I love to see
that Nature is so rife with life that myriads can be afforded to be
sacrificed and suffered to prey on one another; that tender
organizations can be so serenely squashed out of existence like
pulp,—tadpoles which herons gobble up, and tortoises and toads run over
in the road; and that sometimes it has rained flesh and blood! With the
liability to accident, we must see how little account is to be made of
it. The impression made on a wise man is that of universal innocence.
Poison is not poisonous after all, nor are any wounds fatal. Compassion
is a very untenable ground. It must be expeditious. Its pleadings will
not bear to be stereotyped.

Early in May, the oaks, hickories, maples, and other trees, just
putting out amidst the pine woods around the pond, imparted a
brightness like sunshine to the landscape, especially in cloudy days,
as if the sun were breaking through mists and shining faintly on the
hill-sides here and there. On the third or fourth of May I saw a loon
in the pond, and during the first week of the month I heard the
whippoorwill, the brown-thrasher, the veery, the wood-pewee, the
chewink, and other birds. I had heard the wood-thrush long before. The
phœbe had already come once more and looked in at my door and window,
to see if my house was cavern-like enough for her, sustaining herself
on humming wings with clinched talons, as if she held by the air, while
she surveyed the premises. The sulphur-like pollen of the pitch-pine
soon covered the pond and the stones and rotten wood along the shore,
so that you could have collected a barrel-ful. This is the “sulphur
showers” we hear of. Even in Calidas’ drama of Sacontala, we read of
“rills dyed yellow with the golden dust of the lotus.” And so the
seasons went rolling on into summer, as one rambles into higher and
higher grass.

Thus was my first year’s life in the woods completed; and the second
year was similar to it. I finally left Walden September 6th, 1847.


